==> zio-aws-ssm_2.13-5.17.130.6-sources.jar: zio/aws/ssm/model/DescribeInstancePatchStatesForPatchGroupResponse.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.NextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeInstancePatchStatesForPatchGroupResponse(
    instancePatchStates: Option[
      Iterable[zio.aws.ssm.model.InstancePatchState]
    ] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse = {
    import DescribeInstancePatchStatesForPatchGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse
      .builder()
      .optionallyWith(
        instancePatchStates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.instancePatchStates)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse.ReadOnly =
    zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse
      .wrap(buildAwsValue())
}
object DescribeInstancePatchStatesForPatchGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse =
      zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse(
        instancePatchStates.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def instancePatchStates
        : Option[List[zio.aws.ssm.model.InstancePatchState.ReadOnly]]
    def nextToken: Option[NextToken]
    def getInstancePatchStates: ZIO[Any, AwsError, List[
      zio.aws.ssm.model.InstancePatchState.ReadOnly
    ]] = AwsError.unwrapOptionField("instancePatchStates", instancePatchStates)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse
  ) extends zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse.ReadOnly {
    override val instancePatchStates
        : Option[List[zio.aws.ssm.model.InstancePatchState.ReadOnly]] = scala
      .Option(impl.instancePatchStates())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ssm.model.InstancePatchState.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.ssm.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse
  ): zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ssm_2.13-5.17.201.2-sources.jar: zio/aws/ssm/model/DescribeInstancePatchStatesForPatchGroupResponse.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.NextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeInstancePatchStatesForPatchGroupResponse(
    instancePatchStates: Optional[
      Iterable[zio.aws.ssm.model.InstancePatchState]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse = {
    import DescribeInstancePatchStatesForPatchGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse
      .builder()
      .optionallyWith(
        instancePatchStates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.instancePatchStates)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse.ReadOnly =
    zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse
      .wrap(buildAwsValue())
}
object DescribeInstancePatchStatesForPatchGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse =
      zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse(
        instancePatchStates.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def instancePatchStates
        : Optional[List[zio.aws.ssm.model.InstancePatchState.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getInstancePatchStates: ZIO[Any, AwsError, List[
      zio.aws.ssm.model.InstancePatchState.ReadOnly
    ]] = AwsError.unwrapOptionField("instancePatchStates", instancePatchStates)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse
  ) extends zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse.ReadOnly {
    override val instancePatchStates
        : Optional[List[zio.aws.ssm.model.InstancePatchState.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.instancePatchStates())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ssm.model.InstancePatchState.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.ssm.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse
  ): zio.aws.ssm.model.DescribeInstancePatchStatesForPatchGroupResponse.ReadOnly =
    new Wrapper(impl)
}
